--- c_src/memsup.c	Mon Aug 14 20:44:48 CEST 2006
+++ c_src/memsup.c.irix	Mon Aug 14 20:46:03 CEST 2006
@@ -66,6 +66,11 @@
  *  the preprocessor (usually by a -D option).
  */
 
+#ifdef sgi
+#include <sys/types.h>
+#include <sys/sysmp.h>
+#endif
+
 #include <stdio.h>
 #include <stddef.h>
 #include <stdlib.h>
@@ -226,6 +231,15 @@
 fail:
     print_error("%s", strerror(errno));
     exit(1);
+#elif defined(sgi)
+	struct rminfo rmi;
+	if (sysmp(MP_SAGET, MPSA_RMINFO, &rmi, sizeof(rmi)) != -1) {
+		*tot = (unsigned long)(rmi.physmem);
+		*used = (unsigned long)(rmi.physmem - rmi.freemem);
+		*pagesize = (unsigned long)getpagesize(); }
+	else {
+		print_error("%s", strerror(errno));
+		exit(1); }
 #else  /* SunOS4 */
 	 int shiftleft = 1;
     *used = (1<<27) >> shiftleft;	       	/* Fake! 128 MB used */

--- src/cpu_sup.erl	Mon Aug 14 20:46:23 CEST 2006
+++ src/cpu_sup.erl.irix	Mon Aug 14 20:53:59 CEST 2006
@@ -121,7 +121,11 @@
 	       {unix, Flavor} when Flavor==darwin;
 				   Flavor==freebsd;
 				   Flavor==linux;
-				   Flavor==openbsd ->
+				   Flavor==openbsd;
+% IRIX hacks
+				   Flavor==irix64;
+				   Flavor==irix ->
+% IRIX hacks
 		   not_used;
 	       _ ->
 		   exit({unsupported_os, OS})
@@ -151,6 +155,15 @@
 			       PerCpu,
 			       fun () -> linux_read_cpu_util() end,
 			       State);
+%% IRIX hacks
+%handle_call({?util, Detailed, PerCpu}, {Client, _Tag},
+%	    #state{os_type = {unix, Sys}} = State) when Sys == irix64; Sys == irix->
+%    get_util_measurement_reply(Client,
+%			       Detailed,
+%			       PerCpu,
+%			       fun () -> irix_read_cpu_util() end,
+%			       State);
+%% IRIX hacks
 handle_call({?util, _Detailed, _PerCpu}, _From, State) ->
     String = "OS_MON (cpu_sup), util/1 unavailable for this OS~n",
     error_logger:warning_msg(String),
@@ -291,7 +304,23 @@
 	    Ps = os:cmd("/bin/ps -ax | /usr/bin/wc -l"),
 	    {ok, [N], _} = io_lib:fread("~d", Ps),
 	    N-1
-    end.
+    end;
+%% IRIX hacks
+get_int_measurement(Request, #state{os_type = {unix, Sys}}) when Sys == irix64; Sys == irix ->
+	%% Get the load average using uptime.
+	%% "8:01pm  up 2 days, 22:12,  4 users,  load average: 0.70, 0.58, 0.43"
+	D = os:cmd("uptime") -- "\n",
+	Avg = lists:reverse(hd(string:tokens(lists:reverse(D), ":"))),
+	{ok, [L1, L5, L15], _} = io_lib:fread("~f, ~f, ~f", Avg),
+	case Request of
+		?avg1  -> sunify(L1);
+		?avg5  -> sunify(L5);
+		?avg15 -> sunify(L15);
+		?ping -> 4711;
+		?nprocs ->
+			{ok, ProcList} = file:list_dir("/proc/pinfo"),
+			length(ProcList) end.
+%% IRIX hacks
 
 sunify(Val)  ->
     round(Val*256). % Note that Solaris and Linux load averages are
--- src/disksup.erl	Mon Aug 14 20:49:49 CEST 2006
+++ src/disksup.erl.irix	Mon Aug 14 20:52:43 CEST 2006
@@ -100,7 +100,11 @@
 				    Flavor==freebsd;
 				    Flavor==darwin;
 				    Flavor==linux;
-				    Flavor==openbsd ->
+				    Flavor==openbsd;
+%% IRIX hacks
+				    Flavor==irix64;
+				    Flavor==irix ->
+%% IRIX hacks
 		   start_portprogram();
 	       {win32, _OSname} ->
 		   not_used;
@@ -208,6 +212,9 @@
 		{4,_,_} -> {unix, sunos4};
 		V -> exit({unknown_os_version, V})
 	    end;
+%% IRIX hacks
+        {unix, irix64} -> {unix, irix};
+%% IRIX hacks
 	OS ->
 	    OS
     end.
@@ -247,6 +254,11 @@
 check_disk_space({unix, solaris}, Port, Threshold) ->
     Result = my_cmd("/usr/bin/df -lk", Port),
     check_disks_solaris(skip_to_eol(Result), Threshold);
+%% IRIX hacks
+check_disk_space({unix, irix}, Port, Threshold) ->
+    Result = my_cmd("/usr/sbin/df -lk",Port),
+    check_disks_irix(skip_to_eol(Result), Threshold);
+%% IRIX hacks
 check_disk_space({unix, linux}, Port, Threshold) ->
     Result = my_cmd("/bin/df -lk", Port),
     check_disks_solaris(skip_to_eol(Result), Threshold);
@@ -283,6 +295,20 @@
 	    check_disks_solaris(skip_to_eol(Str),Threshold)
     end.
 
+%% IRIX hacks
+%% like Linux with an extra FS type column and no '%'
+check_disks_irix("", _Threshold) -> [];
+check_disks_irix("\n", _Threshold) -> [];
+check_disks_irix(Str, Threshold) ->
+	case io_lib:fread("~s~s~d~d~d~d~s", Str) of
+		{ok, [_FS, _FSType, KB, _Used, _Avail, Cap, MntOn], RestStr} ->
+			if Cap >= Threshold -> set_alarm({disk_almost_full, MntOn}, []);
+			   true             -> clear_alarm({disk_almost_full, MntOn}) end,
+			[{MntOn, KB, Cap} | check_disks_irix(RestStr, Threshold)];
+		_Other ->
+			check_disks_irix(skip_to_eol(Str),Threshold) end.
+%% IRIX hacks
+ 
 check_disks_win32([], _Threshold) ->
     [];
 check_disks_win32([H|T], Threshold) ->

--- src/memsup.erl	Mon Aug 14 20:52:48 CEST 2006
+++ src/memsup.erl.irix	Mon Aug 14 20:54:03 CEST 2006
@@ -171,6 +171,10 @@
 		   {unix, freebsd} -> false;
 		   {unix, linux} -> false;
 		   {unix, openbsd} -> true;
+% IRIX hacks
+		   {unix, irix64} -> true;
+		   {unix, irix} -> true;
+% IRIX hacks
 		   {unix, sunos} -> true;
 		   {win32, _OSname} -> false;
 		   vxworks -> true;

--- src/os_mon.erl	Mon Aug 14 20:54:09 CEST 2006
+++ src/os_mon.erl.irix	Mon Aug 14 20:55:21 CEST 2006
@@ -156,7 +156,7 @@
 
 services({unix, sunos}) ->
     [cpu_sup, disksup, memsup, os_sup];
-services({unix, _}) -> % darwin | freebsd | linux | openbsd
+services({unix, _}) -> % darwin | freebsd | linux | openbsd | irix[64]
     [cpu_sup, disksup, memsup];
 services({win32, _}) ->
     [disksup, memsup, os_sup, sysinfo];

